from setuptools import setup

setup(
    name='vsearch',
    version='1.1.0',
    description='The Head First Python Search Tools',
    author='Zehthijs',
    author_email    = 'zehthijs@zehthijs.nl',
    url             = 'http://www.zehthijs.nl',
    py_modules=['vsearchZT'],
)
